pygeodesy.auxilats._CX_4

Package pygeodesy :: Package auxilats :: Module _CX_4 |
[frames] | no frames]

# Module _CX_4

Coefficients for `_AUXLATITUDE_ORDER` 4 from Karney's C++ class AuxLatitude transcoded to a Python `_Rdict[auxout][auxin]` of `_Rtuple`s.

Copyright (C) Charles Karney (2022-2024) Karney@Alum.MIT.edu> and licensed under the MIT/X11 License. For more information, see <https://GeographicLib.SourceForge.io>.

Version: 25.04.09